# Utilities
This module holds bits of code that are quite generic and don't fit anywhere
else.

## Mathematical functions

::: extra.utils.gaussian

::: extra.utils.gaussian2d

::: extra.utils.lorentzian

## Array functions

::: extra.utils.find_nearest_index

::: extra.utils.find_nearest_value

::: extra.utils.reorder_axes_to_shape

## Plotting functions

::: extra.utils.imshow2

::: extra.utils.hyperslicer2

## Fitting functions

::: extra.utils.fit_gaussian
